# Файл для включения в проект на CMAKE, чтобы встроить библиотеку в код программы.
# Перед включением необходимо определить переменные
#    LMATH_DIR      - путь к директории, где находится lmath.cmake
#    LMATH_USE_FFTW - включать ли код, использующий библиотеку FFTW
#
# После включения будут установлены следующие перменные:
#   LMATH_HEADERS       - используемые заголовочные файлы
#   LMATH_SOURCES       - используемые файлы исходных кодов
#   LMATH_LIBS          - используемые библиотеки
#   LMATH_CONFIG_FILE   - результирующий файл конфигурации

set(LMATH_SOURCES ${LMATH_DIR}/lmath.c)
set(LMATH_HEADERS ${LMATH_DIR}/lmath.h)


if(LMATH_USE_FFTW)
    get_filename_component(LMATH_MODULES_PATH "${LMATH_DIR}/cmake/Modules/" ABSOLUTE)
    set(CMAKE_MODULE_PATH ${CMAKE_MODULE_PATH} ${LMATH_MODULES_PATH})
    find_package(FFTW3 REQUIRED)

    include_directories(${FFTW3_INCLUDE_DIRS})
    set(LMATH_LIBS ${LMATH_LIBS} ${FFTW3_LIBRARIES})
endif(LMATH_USE_FFTW)

if(UNIX)
    set(LMATH_LIBS ${LMATH_LIBS} m)
endif(UNIX)

configure_file(${LMATH_DIR}/lmath_config.h.in ${CMAKE_CURRENT_BINARY_DIR}/lmath_config.h)
set(LMATH_CONFIG_FILE ${CMAKE_CURRENT_BINARY_DIR}/lmath_config.h)
include_directories(${CMAKE_CURRENT_BINARY_DIR})
